Integrating sphere how to Readme
================================


[![License MIT](http://img.shields.io/badge/license-MIT-brightgreen.svg)](license.md)
[![Version](http://img.shields.io/badge/version-2.2-brightgreen.svg)](https://gitlab.com/fabriziodifran/esfera-codigo-verilog/blob/master/Menu_frontend.py)

## Author(s)
*   Victor Esparza
*   Fabrizio Di Francesco
--------------------------------------------------------------------------------
## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on your system.

--------------------------------------------------------------------------------
### Prerequisites

What things you need to install the software and how to install them:

*   Python 2.7 and or 3.7.1 (latest version)
*   pip (latest version)
The rest of the needed packages is going to be installed as a dependency from pip repo.
--------------------------------------------------------------------------------

## Installing process

Navigate to pip repo [pip](https://pypi.org/project/iteda/)

All you need is to execute the command displayed in your favourite terminal.


### Using Iteda software (Unix/Linux/Windows/MacOS)

`Unix/Linux`

    open a terminal
    cd ~/.local/lib/python2.7/site-packages/iteda  ## this might change depending on the version you are executing
    python iteda.py  ## if you need to see the help add -h to the command

`Windows`

    open a terminal
    cd C:\Python27\Lib\site-packages\iteda ## this might change depending on the version you are executing
    python iteda.py  ## if you need to see the help add -h to the command

`MacOS`

    open a terminal
    cd ~/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7/site-packages/iteda  ## this might change depending on the version you are executing
    python iteda.py  ## if you need to see the help add -h to the command

## Versioning

We use [GitKraken](https://www.gitkraken.com) for versioning.

## Acknowledgments

* A big thank you to all the iteda team